@@ -8,7 +8,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(format_pretty);
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 sub content_type { "application/json" }
 
@@ -23,8 +23,8 @@ sub format_pretty {
         JSON::Color::encode_json($data, {pretty=>0, linum=>0});
     } else {
         if (!$json) {
-            require JSON;
-            $json = JSON->new->utf8->allow_nonref;
+            require JSON::MaybeXS;
+            $json = JSON::MaybeXS->new->utf8->allow_nonref;
         }
         $json->encode($data);
     }
@@ -45,7 +45,7 @@ Data::Format::Pretty::CompactJSON - Pretty-print data structure as compact JSON
 
 =head1 VERSION
 
-This document describes version 0.11 of Data::Format::Pretty::CompactJSON (from Perl distribution Data-Format-Pretty-JSON), released on 2014-12-10.
+This document describes version 0.12 of Data::Format::Pretty::CompactJSON (from Perl distribution Data-Format-Pretty-JSON), released on 2016-03-11.
 
 =head1 SYNOPSIS
 
@@ -92,10 +92,6 @@ Return C<application/json>.
 
 Set C<color> option (if unset).
 
-=head1 SEE ALSO
-
-L<Data::Format::Pretty::JSON>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Format-Pretty-JSON>.
@@ -112,13 +108,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Data::Format::Pretty::JSON>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
